pub enum RemoveEdgeOutcome {
RemovedFromOverlay,
TombstonedBase,
}Expand description
Outcome of Topology::remove_edge, distinguishing the two “not removed from overlay”
cases that have different semantics for callers aware of a base CSR.
Variants
RemovedFromOverlay
Edge was present in the overlay and has been removed. edge_count was decremented.
TombstonedBase
Edge was NOT present in the overlay. A tombstone has been recorded in both
out_tombstones and in_tombstones so TopologyView::neighbors will subtract
it from the base CSR during reads and snapshot-merges. The edge may or may not
exist in the base CSR — the tombstone is a no-op if it does not.