pub struct CsrAdjMap {
pub rows: Vec<CsrRow>,
}Expand description
All adjacency rows for one direction (out or in) of one edge type.
Rows are sorted by vertex ascending so lookups can binary-search.
Fields
rows: Vec<CsrRow>Trait Implementations
Sourceimpl Archive for CsrAdjMap
impl Archive for CsrAdjMap
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCsrAdjMap
type Archived = ArchivedCsrAdjMap
The archived representation of this type. Read more
Sourcetype Resolver = CsrAdjMapResolver
type Resolver = CsrAdjMapResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.