pub struct EdgePropsData {
pub entries: Vec<EdgePropEntry>,
}Expand description
All archived edge properties, sorted by (etype, src, dst).
Fields
entries: Vec<EdgePropEntry>Trait Implementations
Sourceimpl Archive for EdgePropsData
impl Archive for EdgePropsData
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedEdgePropsData
type Archived = ArchivedEdgePropsData
The archived representation of this type. Read more
Sourcetype Resolver = EdgePropsDataResolver
type Resolver = EdgePropsDataResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for EdgePropsData
impl Clone for EdgePropsData
Sourcefn clone(&self) -> EdgePropsData
fn clone(&self) -> EdgePropsData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EdgePropsData
impl Debug for EdgePropsData
Sourceimpl<__D: Fallible + ?Sized> Deserialize<EdgePropsData, __D> for Archived<EdgePropsData>where
Vec<EdgePropEntry>: Archive,
<Vec<EdgePropEntry> as Archive>::Archived: Deserialize<Vec<EdgePropEntry>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<EdgePropsData, __D> for Archived<EdgePropsData>where
Vec<EdgePropEntry>: Archive,
<Vec<EdgePropEntry> as Archive>::Archived: Deserialize<Vec<EdgePropEntry>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<EdgePropsData, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<EdgePropsData, <__D as Fallible>::Error>
Deserializes using the given deserializer