Interner

Struct Interner 

pub struct Interner { /* private fields */ }

Implementations

Source

impl Interner

pub fn new() -> Self

pub fn intern(&mut self, s: &str) -> u32

pub fn resolve(&self, sym: u32) -> Option<&str>

pub fn get(&self, s: &str) -> Option<u32>

pub fn len(&self) -> usize

Number of interned symbols (also the id intern assigns next).

pub fn is_empty(&self) -> bool

pub fn truncate(&mut self, len: usize)

Roll back to the first len symbols. Ids are assigned densely and never persisted before their WAL record, so dropping the tail is the exact inverse of the speculative intern calls made since len was captured. No-op if len >= self.len().